@@ -1,6 +1,6 @@
-module YARD
-  VERSION = "0.8.2.1"
+require File.expand_path('../yard/version.rb', __FILE__)
 
+module YARD
   # The root path for YARD source libraries
   ROOT = File.expand_path(File.dirname(__FILE__))
 
@@ -27,10 +27,33 @@ module YARD
   # (see YARD::Config.load_plugins)
   # @deprecated Use {Config.load_plugins}
   def self.load_plugins; YARD::Config.load_plugins end
+
+  # @return [Boolean] whether YARD is being run inside of Windows
+  def self.windows?
+    return @windows if defined? @windows
+    require 'rbconfig'
+    if ::RbConfig::CONFIG['host_os'] =~ /mingw|win32|cygwin/
+      @wnidows = true
+    else
+      @windows = false
+    end
+  ensure
+    @windows ||= false
+  end
+
+  # @return [Boolean] whether YARD is being run in Ruby 1.8 mode
+  def self.ruby18?; !ruby19? end
+
+  # @return [Boolean] whether YARD is being run in Ruby 1.9 mode
+  def self.ruby19?; @ruby19 ||= (RUBY_VERSION >= "1.9.1") end
+
+  # @return [Boolean] whether YARD is being run in Ruby 2.0
+  def self.ruby2?; @ruby2 ||= (RUBY_VERSION >= '2.0.0') end
 end
 
 # Keep track of Ruby version for compatibility code
-RUBY19, RUBY18 = *(RUBY_VERSION >= "1.9.1" ? [true, false] : [false, true])
+# @deprecated Use {YARD.ruby18?} or {YARD.ruby19?} instead.
+RUBY18, RUBY19 = YARD.ruby18?, YARD.ruby19?
 
 # Load Ruby core extension classes
 Dir.glob(File.join(YARD::ROOT, 'yard', 'core_ext', '*.rb')).each do |file|
