@@ -3,19 +3,22 @@ def __p(path) File.join(YARD::ROOT, 'yard', *path.split('/')); end
 
 module YARD
   module CLI # Namespace for command-line interface components
-    autoload :Command,        __p('cli/command')
-    autoload :CommandParser,  __p('cli/command_parser')
-    autoload :Config,         __p('cli/config')
-    autoload :Diff,           __p('cli/diff')
-    autoload :Gems,           __p('cli/gems')
-    autoload :Graph,          __p('cli/graph')
-    autoload :Help,           __p('cli/help')
-    autoload :List,           __p('cli/list')
-    autoload :Server,         __p('cli/server')
-    autoload :Stats,          __p('cli/stats')
-    autoload :Yardoc,         __p('cli/yardoc')
-    autoload :YRI,            __p('cli/yri')
-    autoload :I18n,           __p('cli/i18n')
+    autoload :Command,         __p('cli/command')
+    autoload :CommandParser,   __p('cli/command_parser')
+    autoload :Config,          __p('cli/config')
+    autoload :Diff,            __p('cli/diff')
+    autoload :Display,         __p('cli/display')
+    autoload :Gems,            __p('cli/gems')
+    autoload :Graph,           __p('cli/graph')
+    autoload :Help,            __p('cli/help')
+    autoload :List,            __p('cli/list')
+    autoload :MarkupTypes,     __p('cli/markup_types')
+    autoload :Server,          __p('cli/server')
+    autoload :Stats,           __p('cli/stats')
+    autoload :Yardoc,          __p('cli/yardoc')
+    autoload :YardoptsCommand, __p('cli/yardopts_command')
+    autoload :YRI,             __p('cli/yri')
+    autoload :I18n,            __p('cli/i18n')
   end
 
   # A "code object" is defined as any entity in the Ruby language.
@@ -126,6 +129,7 @@ module YARD
     end
 
     autoload :Base,                       __p('handlers/base')
+    autoload :HandlerAborted,             __p('handlers/base')
     autoload :NamespaceMissingError,      __p('handlers/base')
     autoload :Processor,                  __p('handlers/processor')
   end
@@ -229,6 +233,7 @@ module YARD
     autoload :AttributeDirective,  __p('tags/directives')
     autoload :DefaultFactory,      __p('tags/default_factory')
     autoload :DefaultTag,          __p('tags/default_tag')
+    autoload :Directive,           __p('tags/directives')
     autoload :EndGroupDirective,   __p('tags/directives')
     autoload :GroupDirective,      __p('tags/directives')
     autoload :Library,             __p('tags/library')
@@ -250,6 +255,7 @@ module YARD
     module Helpers # Namespace for template helpers
       module Markup # Namespace for markup providers
         autoload :RDocMarkup,               __p('templates/helpers/markup/rdoc_markup')
+        autoload :RDocMarkdown,             __p('templates/helpers/markup/rdoc_markdown')
       end
 
       autoload :BaseHelper,                 __p('templates/helpers/base_helper')
