@@ -10,7 +10,7 @@ class YARD::Handlers::Ruby::AliasHandler < YARD::Handlers::Ruby::Base
     elsif statement.call?
       statement.parameters(false).each do |obj|
         case obj.type
-        when :symbol_literal
+        when :symbol_literal, :dyna_symbol
           names << obj.jump(:ident, :op, :kw, :const).source
         when :string_literal
           names << obj.jump(:string_content).source
@@ -22,8 +22,6 @@ class YARD::Handlers::Ruby::AliasHandler < YARD::Handlers::Ruby::Base
     new_meth, old_meth = names[0].to_sym, names[1].to_sym
     old_obj = namespace.child(:name => old_meth, :scope => scope)
     new_obj = register MethodObject.new(namespace, new_meth, scope) do |o|
-      o.visibility = visibility
-      o.scope = scope
       o.add_file(parser.file, statement.line)
     end
 
