@@ -29,20 +29,20 @@ class YARD::Handlers::Ruby::MethodHandler < YARD::Handlers::Ruby::Base
       nobj.aliases.delete(aobj)
     end if nobj.is_a?(NamespaceObject)
 
-    if mscope == :instance && meth == "initialize"
+    if obj.constructor?
       unless obj.has_tag?(:return)
-        obj.docstring.add_tag(YARD::Tags::Tag.new(:return,
+        obj.add_tag(YARD::Tags::Tag.new(:return,
           "a new instance of #{namespace.name}", namespace.name.to_s))
       end
     elsif mscope == :class && obj.docstring.blank? && %w(inherited included
         extended method_added method_removed method_undefined).include?(meth)
-      obj.docstring.add_tag(YARD::Tags::Tag.new(:private, nil))
+      obj.add_tag(YARD::Tags::Tag.new(:private, nil))
     elsif meth.to_s =~ /\?$/
       if obj.tag(:return) && (obj.tag(:return).types || []).empty?
         obj.tag(:return).types = ['Boolean']
       elsif obj.tag(:return).nil?
         unless obj.tags(:overload).any? {|overload| overload.tag(:return) }
-          obj.docstring.add_tag(YARD::Tags::Tag.new(:return, "", "Boolean"))
+          obj.add_tag(YARD::Tags::Tag.new(:return, "", "Boolean"))
         end
       end
     end
@@ -53,7 +53,7 @@ class YARD::Handlers::Ruby::MethodHandler < YARD::Handlers::Ruby::Base
         expected_param = option.name
         unless obj.tags(:param).find {|x| x.name == expected_param }
           new_tag = YARD::Tags::Tag.new(:param, "a customizable set of options", "Hash", expected_param)
-          obj.docstring.add_tag(new_tag)
+          obj.add_tag(new_tag)
         end
       end
     end
@@ -75,6 +75,7 @@ class YARD::Handlers::Ruby::MethodHandler < YARD::Handlers::Ruby::Base
     params += args.required_params.map {|a| [a.source, nil] } if args.required_params
     params += args.optional_params.map {|a| [a[0].source, a[1].source] } if args.optional_params
     params << ["*" + args.splat_param.source, nil] if args.splat_param
+    params << ["**" + args.keyword_param.source, nil] if args.keyword_param
     params += args.required_end_params.map {|a| [a.source, nil] } if args.required_end_params
     params << ["&" + args.block_param.source, nil] if args.block_param
     params
@@ -88,4 +89,4 @@ class YARD::Handlers::Ruby::MethodHandler < YARD::Handlers::Ruby::Base
       "def #{method_name}"
     end
   end
-end
\ No newline at end of file
+end
