@@ -60,12 +60,20 @@ module YARD
         if provider.to_s == 'RDiscount'
           provider.new(text, :autolink).to_html
         elsif provider.to_s == 'RedcarpetCompat'
-          provider.new(text, :gh_blockcode, :fenced_code, :autolink).to_html
+          provider.new(text, :no_intraemphasis, :gh_blockcode,
+                             :fenced_code, :autolink).to_html
         else
           provider.new(text).to_html
         end
       end
 
+      # Converts Asciidoc to HTML
+      # @param [String] text input Asciidoc text
+      # @return [String] output HTML
+      def html_markup_asciidoc(text)
+        markup_class(:asciidoc).render(text)
+      end
+
       # Converts Textile to HTML
       # @param [String] text the input Textile text
       # @return [String] output HTML
@@ -242,19 +250,19 @@ module YARD
       end
 
       # (see BaseHelper#link_object)
-      def link_object(obj, otitle = nil, anchor = nil, relative = true)
-        return otitle if obj.nil?
+      def link_object(obj, title = nil, anchor = nil, relative = true)
+        return title if obj.nil?
         obj = Registry.resolve(object, obj, true, true) if obj.is_a?(String)
-        if !otitle && obj.root?
-          title = "Top Level Namespace"
-        elsif otitle
-          title = otitle.to_s
+        if title
+          title = title.to_s
         elsif object.is_a?(CodeObjects::Base)
           # Check if we're linking to a class method in the current
           # object. If we are, create a title in the format of
           # "CurrentClass.method_name"
           if obj.is_a?(CodeObjects::MethodObject) && obj.scope == :class && obj.parent == object
             title = h([object.name, obj.sep, obj.name].join)
+          elsif obj.title != obj.path
+            title = h(obj.title)
           else
             title = h(object.relative_path(obj))
           end
@@ -265,7 +273,7 @@ module YARD
         return title if obj.is_a?(CodeObjects::Proxy)
 
         link = url_for(obj, anchor, relative)
-        link = link ? link_url(link, title, :title => h("#{obj.path} (#{obj.type})")) : title
+        link = link ? link_url(link, title, :title => h("#{obj.title} (#{obj.type})")) : title
         "<span class='object_link'>" + link + "</span>"
       end
 
@@ -309,6 +317,7 @@ module YARD
       def url_for(obj, anchor = nil, relative = true)
         link = nil
         return link unless serializer
+        return link if obj.is_a?(CodeObjects::Base) && run_verifier([obj]).empty?
 
         if obj.is_a?(CodeObjects::Base) && !obj.is_a?(CodeObjects::NamespaceObject)
           # If the obj is not a namespace obj make it the anchor.
@@ -508,11 +517,12 @@ module YARD
       # @return [String] the current character set
       # @since 0.5.4
       def charset
-        if @file && RUBY19
+        has_encoding = defined?(::Encoding)
+        if @file && has_encoding
           lang = @file.contents.encoding.to_s
         else
-          return 'utf-8' unless RUBY19 || lang = ENV['LANG']
-          if RUBY19
+          return 'utf-8' unless has_encoding || lang = ENV['LANG']
+          if has_encoding
             lang = ::Encoding.default_external.name.downcase
           else
             lang = lang.downcase.split('.').last
@@ -580,7 +590,7 @@ module YARD
             string = html_syntax_highlight(CGI.unescapeHTML(string), language)
           end
           classes = ['code', language].compact.join(' ')
-          %Q{<pre class="#{classes}"><code>#{string}</code></pre>}
+          %Q{<pre class="#{classes}"><code class="#{language}">#{string}</code></pre>}
         end
       end
     end
