@@ -77,6 +77,10 @@ describe YARD::CLI::Yardoc do
     it "should not embed mixins by default" do
       @yardoc.options.embed_mixins.should be_empty
     end
+
+    it "should not set any locale by default" do
+      @yardoc.options.locale.should be_nil
+    end
   end
 
   describe 'General options' do
@@ -303,6 +307,32 @@ describe YARD::CLI::Yardoc do
         end
       end
     end
+
+    describe '--locale' do
+      it 'should apply specified locale to all extra file objects' do
+        File.stub!(:read).with('extra_file1').and_return('')
+        File.stub!(:read).with('extra_file2').and_return('')
+
+        extra_file_object1 = CodeObjects::ExtraFileObject.new('extra_file1')
+        extra_file_object2 = CodeObjects::ExtraFileObject.new('extra_file2')
+        extra_file_object1.should_receive(:locale=).with('fr')
+        extra_file_object2.should_receive(:locale=).with('fr')
+
+        CodeObjects::ExtraFileObject.stub!(:new).with('extra_file1').and_return(extra_file_object1)
+        CodeObjects::ExtraFileObject.stub!(:new).with('extra_file2').and_return(extra_file_object2)
+        Dir.stub!(:glob).with('README*').and_return([])
+        File.stub!(:file?).with('extra_file1').and_return(true)
+        File.stub!(:file?).with('extra_file2').and_return(true)
+        @yardoc.run('--locale=fr', '-', 'extra_file1', 'extra_file2')
+      end
+    end
+
+    describe '--po-dir' do
+      it 'should set Registry.po_dir' do
+        Registry.should_receive(:po_dir=).with("locale")
+        @yardoc.run('--po-dir=locale')
+      end
+    end
   end
 
   describe '--[no-]api' do
@@ -370,6 +400,33 @@ describe YARD::CLI::Yardoc do
     end
   end
 
+  describe '--hide-api option' do
+    it "should allow --hide-api to hide objects with api tags" do
+      YARD.parse_string <<-eof
+        # @api private
+        class Foo; end
+        class Bar; end
+        class Baz; end
+      eof
+      @yardoc.run('--hide-api', 'private')
+      @yardoc.options.verifier.run(Registry.all).
+        sort_by {|o| o.path }.should == [P('Bar'), P('Baz')]
+    end
+
+    it "should allow --hide-api to work with --api" do
+      YARD.parse_string <<-eof
+        # @api private
+        class Foo; end
+        # @api public
+        class Bar; end
+        class Baz; end
+      eof
+      @yardoc.run('--api', 'public', '--hide-api', 'private')
+      @yardoc.options.verifier.run(Registry.all).
+        sort_by {|o| o.path }.should == [P('Bar')]
+    end
+  end
+
   describe '--no-private option' do
     it "should accept --no-private" do
       obj = mock(:object)
@@ -651,6 +708,12 @@ describe YARD::CLI::Yardoc do
       @yardoc.parse_arguments('--transitive-tag', 'foo')
       Tags::Library.transitive_tags.should include(:foo)
     end
+
+    it "should accept --non-transitive-tag" do
+      Tags::Library.transitive_tags |= [:foo]
+      @yardoc.parse_arguments('--non-transitive-tag', 'foo')
+      Tags::Library.transitive_tags.should_not include(:foo)
+    end
   end
 
   describe 'Safe mode' do
