@@ -87,6 +87,32 @@ describe YARD::Parser::Ruby::RubyParser do
       ss[2].comments.should == 'hello'
     end
 
+    it "should handle block comment followed by line comment" do
+      ss = stmts <<-eof
+# comments1
+
+=begin
+comments2
+=end
+# comments3
+def hello; end
+eof
+      ss.last.comments.should == "comments3"
+    end
+
+    it "should handle block comment followed by block comment" do
+      ss = stmts <<-eof
+=begin
+comments1
+=end
+=begin
+comments2
+=end
+def hello; end
+eof
+      ss.last.comments.strip.should == "comments2"
+    end
+
     it "should handle 1.9 lambda syntax with args" do
       src = "->(a,b,c=1,*args,&block) { hello_world }"
       stmt(src).source.should == src
@@ -270,6 +296,19 @@ describe YARD::Parser::Ruby::RubyParser do
       stmt("X = !1").jump(:unary).source.should == '!1'
     end
 
+    it "should have the correct line range for class/modules" do
+      s = stmt(<<-eof)
+        class Foo
+          def foo; end
+
+
+
+          # Ending comment
+        end
+      eof
+      s.jump(:class).line_range.should == (1..7)
+    end
+
     it "should find lone comments" do
       Registry.clear
       ast = YARD.parse_string(<<-eof).enumerator
