@@ -5,6 +5,25 @@ rescue LoadError
   require "spec"
 end
 
+begin
+  require 'bundler'
+  Bundler.setup
+rescue LoadError
+end
+
+begin
+  require 'simplecov'
+  SimpleCov.start
+  # TODO: hide some rb files from cov report
+  # hide = '_spec\.rb$,spec_helper\.rb$,ruby_lex\.rb$,autoload\.rb$'
+  # if YARD::Parser::SourceParser.parser_type == :ruby
+  #   hide += ',legacy\/.+_handler'
+  # else
+  #   hide += ',ruby_parser\.rb$,ast_node\.rb$,handlers\/ruby\/[^\/]+\.rb$'
+  # end
+rescue LoadError
+end if ENV['COVERAGE']
+
 require File.expand_path(File.join(File.dirname(__FILE__), '..', 'lib', 'yard'))
 
 unless defined?(HAVE_RIPPER)
@@ -33,7 +52,7 @@ def described_in_docs(klass, meth, file = nil)
   else
     underscore = klass.class_name.gsub(/([a-z])([A-Z])/, '\1_\2').downcase.gsub('::', '/')
     $".find_all {|p| p.include? underscore }.each do |filename|
-      next unless File.exists? filename
+      next unless File.exist? filename
       YARD::Parser::SourceParser.new.parse(filename)
     end
   end
@@ -65,7 +84,7 @@ def docspec(objname = self.class.description, klass = self.class.described_type)
   underscore = klass.class_name.gsub(/([a-z])([A-Z])/, '\1_\2').downcase.gsub('::', '/')
   $".find_all {|p| p.include? underscore }.each do |filename|
     filename = File.join(YARD::ROOT, filename)
-    next unless File.exists? filename
+    next unless File.exist? filename
     YARD::Parser::SourceParser.new.parse(filename)
   end
 
@@ -96,10 +115,14 @@ module Kernel
     args.first
   end
 
-  def puts(str)
+  def puts(str = '')
     STDOUT.puts str + "<br/>\n"
     str
   end
 end if ENV['TM_APP_PATH']
 
+RSpec.configure do |config|
+  config.before(:each) { log.io = StringIO.new }
+end
+
 include YARD
