@@ -22,14 +22,14 @@ describe YARD::Templates::Helpers::HtmlHelper do
 
   describe '#charset' do
     it "should return foo if LANG=foo" do
-      ENV.should_receive(:[]).with('LANG').and_return('shift_jis') if RUBY18
+      ENV.should_receive(:[]).with('LANG').and_return('shift_jis') if YARD.ruby18?
       Encoding.default_external.should_receive(:name).and_return('shift_jis') if defined?(Encoding)
       charset.should == 'shift_jis'
     end
 
     ['US-ASCII', 'ASCII-7BIT', 'ASCII-8BIT'].each do |type|
       it "should convert #{type} to iso-8859-1" do
-        ENV.should_receive(:[]).with('LANG').and_return(type) if RUBY18
+        ENV.should_receive(:[]).with('LANG').and_return(type) if YARD.ruby18?
         Encoding.default_external.should_receive(:name).and_return(type) if defined?(Encoding)
         charset.should == 'iso-8859-1'
       end
@@ -37,7 +37,7 @@ describe YARD::Templates::Helpers::HtmlHelper do
 
     it "should support utf8 as an encoding value for utf-8" do
       type = 'utf8'
-      ENV.should_receive(:[]).with('LANG').and_return(type) if RUBY18
+      ENV.should_receive(:[]).with('LANG').and_return(type) if YARD.ruby18?
       Encoding.default_external.should_receive(:name).and_return(type) if defined?(Encoding)
       charset.should == 'utf-8'
     end
@@ -46,15 +46,15 @@ describe YARD::Templates::Helpers::HtmlHelper do
       @file = OpenStruct.new(:contents => 'foo'.force_encoding('sjis'))
       # not the correct charset name, but good enough
       ['Shift_JIS', 'Windows-31J'].should include(charset)
-    end if RUBY19
+    end if YARD.ruby19?
 
     it "should take file encoding if there is a file" do
-      ENV.stub!(:[]).with('LANG').and_return('utf-8') if RUBY18
+      ENV.stub!(:[]).with('LANG').and_return('utf-8') if YARD.ruby18?
       @file = OpenStruct.new(:contents => 'foo')
       charset.should == 'utf-8'
-    end if RUBY18
+    end if YARD.ruby18?
 
-    if RUBY18
+    if YARD.ruby18?
       it "should return utf-8 if no LANG env is set" do
         ENV.should_receive(:[]).with('LANG').and_return(nil)
         charset.should == 'utf-8'
@@ -115,8 +115,12 @@ describe YARD::Templates::Helpers::HtmlHelper do
 
     it "should handle various encodings" do
       stub!(:object).and_return(Registry.root)
-      Encoding.default_internal = 'utf-8' if defined?(Encoding)
-      htmlify("\xB0\xB1", :text)
+      text = "\xB0\xB1"
+      if defined?(Encoding)
+        Encoding.default_internal = 'utf-8'
+        text = text.force_encoding('binary')
+      end
+      htmlify(text, :text)
       # TODO: add more encoding tests
     end
 
@@ -145,7 +149,9 @@ describe YARD::Templates::Helpers::HtmlHelper do
 
     it "should autolink URLs (markdown specific)" do
       log.enter_level(Logger::FATAL) do
-        pending 'This test depends on markdown' unless markup_class(:markdown)
+        unless markup_class(:markdown).to_s == "RedcarpetCompat"
+          pending 'This test depends on a markdown engine that supports autolinking'
+        end
       end
       htmlify('http://example.com', :markdown).chomp.gsub('&#47;', '/').should ==
         '<p><a href="http://example.com">http://example.com</a></p>'
@@ -205,6 +211,16 @@ describe YARD::Templates::Helpers::HtmlHelper do
       link_object("Bar").should =~ %r{>Bar</a>}
     end
 
+    it "should use #title if overridden" do
+      CodeObjects::ModuleObject.new(:root, :YARD)
+      CodeObjects::ClassObject.new(P('YARD'), :Bar)
+      Registry.at('YARD::Bar').stub(:title).and_return('TITLE!')
+      stub!(:object).and_return(Registry.at('YARD::Bar'))
+      serializer = Serializers::FileSystemSerializer.new
+      stub!(:serializer).and_return(serializer)
+      link_object("Bar").should =~ %r{>TITLE!</a>}
+    end
+
     it "should use relative path to parent class in title" do
       root = CodeObjects::ModuleObject.new(:root, :YARD)
       obj = CodeObjects::ModuleObject.new(root, :SubModule)
@@ -247,6 +263,16 @@ describe YARD::Templates::Helpers::HtmlHelper do
       url_for(P("Mod::Class#meth")).should be_nil
     end
 
+    it "should return nil if object is hidden" do
+      yard = CodeObjects::ModuleObject.new(:root, :YARD)
+
+      stub!(:serializer).and_return Serializers::FileSystemSerializer.new
+      stub!(:object).and_return Registry.root
+      stub!(:options).and_return OpenStruct.new(:verifier => Verifier.new('false'))
+
+      url_for(yard).should be_nil
+    end
+
     it "should return nil if serializer does not implement #serialized_path" do
       stub!(:serializer).and_return Serializers::Base.new
       stub!(:object).and_return Registry.root
@@ -514,7 +540,7 @@ describe YARD::Templates::Helpers::HtmlHelper do
       subject.should_receive(:respond_to?).with('html_syntax_highlight_NAME').and_return(true)
       subject.should_receive(:html_syntax_highlight_NAME).and_return("foobar")
       subject.htmlify('<pre><code>def x; end</code></pre>', :html).should ==
-        '<pre class="code NAME"><code>foobar</code></pre>'
+        '<pre class="code NAME"><code class="NAME">foobar</code></pre>'
     end
 
     it "should add !!!LANG to className in outputted pre tag" do
@@ -523,7 +549,7 @@ describe YARD::Templates::Helpers::HtmlHelper do
       subject.should_receive(:respond_to?).with('html_syntax_highlight_LANG').and_return(true)
       subject.should_receive(:html_syntax_highlight_LANG).and_return("foobar")
       subject.htmlify("<pre><code>!!!LANG\ndef x; end</code></pre>", :html).should ==
-        '<pre class="code LANG"><code>foobar</code></pre>'
+        '<pre class="code LANG"><code class="LANG">foobar</code></pre>'
     end
 
     it "should call html_syntax_highlight_NAME if source starts with !!!NAME" do
@@ -561,17 +587,17 @@ describe YARD::Templates::Helpers::HtmlHelper do
 
     it "shouldn't escape code snippets twice" do
       subject.htmlify('<pre lang="foo"><code>{"foo" => 1}</code></pre>', :html).should ==
-        '<pre class="code foo"><code>{&quot;foo&quot; =&gt; 1}</code></pre>'
+        '<pre class="code foo"><code class="foo">{&quot;foo&quot; =&gt; 1}</code></pre>'
     end
 
     it "should highlight source when matching a pre lang= tag" do
       subject.htmlify('<pre lang="foo"><code>x = 1</code></pre>', :html).should ==
-        '<pre class="code foo"><code>x = 1</code></pre>'
+        '<pre class="code foo"><code class="foo">x = 1</code></pre>'
     end
 
     it "should highlight source when matching a code class= tag" do
       subject.htmlify('<pre><code class="foo">x = 1</code></pre>', :html).should ==
-        '<pre class="code foo"><code>x = 1</code></pre>'
+        '<pre class="code foo"><code class="foo">x = 1</code></pre>'
     end
   end
 
